@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python -W default
 #
 # This is the test script for libpython-pam.  There aren't many stones
 # left unturned.
@@ -8,6 +8,7 @@
 #   python test.py
 #   sudo rm /etc/pam.d/test-pam_python.pam 
 #
+import warnings; warnings.simplefilter('default')
 import os
 import sys
 
